<!DOCTYPE kpartgui>
<kpartgui name="kplayer" version="16">
<MenuBar>
  <Menu name="file" noMerge="1"><text>&amp;File</text>
    <Action name="file_open"/>
    <Action name="file_open_url"/>
    <Menu name="play_list"><text>Play &amp;List</text>
      <ActionList name="play_list"/>
    </Menu>
    <Menu name="file_recent"><text>Play &amp;Recent</text>
      <ActionList name="file_recent"/>
    </Menu>
    <ActionList name="file_devices"/>
    <Action name="subtitles_load"/>
    <Separator lineSeparator="true"/>
    <Action name="file_properties"/>
    <Separator lineSeparator="true"/>
    <Action name="file_quit"/>
  </Menu>
  <Menu name="view" noMerge="1"><text>&amp;View</text>
    <Action name="view_full_screen"/>
    <Separator lineSeparator="true"/>
    <Action name="view_zoom_in"/>
    <Action name="view_zoom_out"/>
    <Separator lineSeparator="true"/>
    <Action name="view_zoom_1_2"/>
    <Action name="view_zoom_1_1"/>
    <Action name="view_zoom_3_2"/>
    <Action name="view_zoom_2_1"/>
    <Action name="view_zoom_5_2"/>
    <Action name="view_zoom_3_1"/>
    <Separator lineSeparator="true"/>
    <Action name="view_original_aspect"/>
    <Action name="view_current_aspect"/>
    <Action name="view_aspect_4_3"/>
    <Action name="view_aspect_16_9"/>
  </Menu>
  <Menu name="player" noMerge="1"><text>&amp;Player</text>
    <Action name="player_play"/>
    <Action name="player_pause"/>
    <Action name="player_stop"/>
    <Separator lineSeparator="true"/>
    <Action name="player_next"/>
    <Action name="player_previous"/>
    <Separator lineSeparator="true"/>
    <Action name="player_loop"/>
    <Action name="player_shuffle"/>
    <Separator lineSeparator="true"/>
    <Menu name="seek"><text>P&amp;osition</text>
      <Action name="player_forward"/>
      <Action name="player_fast_forward"/>
      <Separator lineSeparator="true"/>
      <Action name="player_backward"/>
      <Action name="player_fast_backward"/>
      <Action name="player_start"/>
    </Menu>
    <Menu name="audio"><text>&amp;Audio</text>
      <ActionList name="audio_streams"/>
      <Action name="audio_volume_down"/>
      <Action name="audio_volume_up"/>
      <Action name="audio_mute"/>
      <Separator lineSeparator="true"/>
      <Action name="audio_delay_down"/>
      <Action name="audio_delay_up"/>
    </Menu>
    <Menu name="video"><text>&amp;Video</text>
      <ActionList name="video_streams"/>
      <Action name="video_contrast_down"/>
      <Action name="video_contrast_up"/>
      <Separator lineSeparator="true"/>
      <Action name="video_brightness_down"/>
      <Action name="video_brightness_up"/>
      <Separator lineSeparator="true"/>
      <Action name="video_hue_down"/>
      <Action name="video_hue_up"/>
      <Separator lineSeparator="true"/>
      <Action name="video_saturation_down"/>
      <Action name="video_saturation_up"/>
    </Menu>
    <Menu name="subtitles"><text>S&amp;ubtitles</text>
      <ActionList name="subtitle_streams"/>
      <Action name="subtitles_move_down"/>
      <Action name="subtitles_move_up"/>
      <Separator lineSeparator="true"/>
      <Action name="subtitles_delay_decrease"/>
      <Action name="subtitles_delay_increase"/>
    </Menu>
    <Menu name="advanced"><text>A&amp;dvanced</text>
      <Action name="player_soft_frame_drop"/>
      <Action name="player_hard_frame_drop"/>
    </Menu>
  </Menu>
  <Menu name="library" noMerge="1"><text>&amp;Library</text>
    <Separator lineSeparator="true"/>
    <Action name="library_play"/>
    <Action name="library_play_next"/>
    <Action name="library_queue"/>
    <Action name="library_queue_next"/>
    <Menu name="library_add_to"><text>Add &amp;to</text>
      <ActionList name="library_add_to_playlist"/>
      <Action name="library_add_to_new_playlist"/>
      <Action name="library_add_to_playlists"/>
      <Action name="library_add_to_collection"/>
    </Menu>
    <Separator lineSeparator="true"/>
    <Menu name="library_add"><text>&amp;Add</text>
      <Action name="library_add_files"/>
      <Action name="library_add_url"/>
      <Action name="library_add_group"/>
    </Menu>
    <Action name="library_select_all"/>
    <Action name="library_move_up"/>
    <Action name="library_move_down"/>
    <Action name="library_remove"/>
    <Separator lineSeparator="true"/>
    <Action name="library_rename"/>
    <Menu name="library_edit"><text>&amp;Edit</text>
      <ActionList name="library_edit"/>
    </Menu>
    <Action name="library_properties"/>
    <Separator lineSeparator="true"/>
    <Menu name="library_columns"><text>&amp;Columns</text>
      <ActionList name="library_columns"/>
    </Menu>
    <Menu name="library_go"><text>&amp;Go</text>
      <ActionList name="library_history"/>
      <ActionList name="library_go_to_list"/>
      <Action name="library_go_back"/>
      <Action name="library_go_forward"/>
      <Action name="library_go_up"/>
      <Action name="library_go_down"/>
      <Action name="library_go_to_origin"/>
    </Menu>
  </Menu>
  <Menu name="settings" noMerge="1"><text>&amp;Settings</text>
    <Action name="options_show_menubar"/>
    <Action name="options_show_statusbar"/>
    <Separator lineSeparator="true"/>
    <Action name="options_show_playlist"/>
    <Action name="options_show_library"/>
    <Action name="options_show_log"/>
    <Separator lineSeparator="true"/>
    <Action name="options_show_toolbar"/>
    <Action name="settings_progress_toolbar"/>
    <Action name="settings_volume_toolbar"/>
    <Separator lineSeparator="true"/>
    <Action name="settings_contrast_toolbar"/>
    <Action name="settings_brightness_toolbar"/>
    <Action name="settings_hue_toolbar"/>
    <Action name="settings_saturation_toolbar"/>
    <Separator lineSeparator="true"/>
    <Action name="options_configure_keybinding"/>
    <Action name="options_configure_toolbars"/>
    <Action name="options_configure"/>
  </Menu>
</MenuBar>
<ToolBar name="mainToolBar" noMerge="1"><text>Main Toolbar</text>
  <Action name="file_open"/>
  <Action name="file_open_url"/>
  <Action name="file_properties"/>
  <Separator lineSeparator="true"/>
  <Action name="player_play"/>
  <Action name="player_pause"/>
  <Action name="player_stop"/>
  <Separator lineSeparator="true"/>
  <Action name="view_zoom_in"/>
  <Action name="view_zoom_out"/>
  <Action name="view_maintain_aspect"/>
  <Action name="view_full_screen"/>
  <Separator lineSeparator="true"/>
  <Action name="popup_volume"/>
  <Action name="popup_contrast"/>
  <Action name="popup_brightness"/>
  <Action name="popup_hue"/>
  <Action name="popup_saturation"/>
</ToolBar>
<ToolBar name="playlistToolBar"><text>Playlist Toolbar</text>
  <Action name="player_previous"/>
  <Action name="player_next"/>
  <Action name="player_list"/>
  <Action name="player_loop"/>
  <Action name="player_shuffle"/>
</ToolBar>
<ToolBar name="progressToolBar"><text>Progress Toolbar</text>
  <Action name="player_fast_backward"/>
  <Action name="player_progress"/>
  <Action name="player_fast_forward"/>
</ToolBar>
<ToolBar name="volumeToolBar"><text>Volume Toolbar</text>
  <Action name="settings_volume_toolbar"/>
  <Action name="audio_volume"/>
  <Action name="audio_mute"/>
</ToolBar>
<ToolBar name="contrastToolBar"><text>Contrast Toolbar</text>
  <Action name="settings_contrast_toolbar"/>
  <Action name="video_contrast"/>
</ToolBar>
<ToolBar name="brightnessToolBar"><text>Brightness Toolbar</text>
  <Action name="settings_brightness_toolbar"/>
  <Action name="video_brightness"/>
</ToolBar>
<ToolBar name="hueToolBar"><text>Hue Toolbar</text>
  <Action name="settings_hue_toolbar"/>
  <Action name="video_hue"/>
</ToolBar>
<ToolBar name="saturationToolBar"><text>Saturation Toolbar</text>
  <Action name="settings_saturation_toolbar"/>
  <Action name="video_saturation"/>
</ToolBar>
<Menu name="player_popup">
  <Action name="file_open"/>
  <Action name="file_open_url"/>
  <Menu name="play_list"><text>Play &amp;List</text>
    <ActionList name="play_list"/>
  </Menu>
  <Menu name="file_recent"><text>Play &amp;Recent</text>
    <ActionList name="file_recent"/>
  </Menu>
  <Separator lineSeparator="true"/>
  <Action name="file_properties"/>
  <Separator lineSeparator="true"/>
  <Action name="player_play"/>
  <Action name="player_pause"/>
  <Action name="player_stop"/>
  <Separator lineSeparator="true"/>
  <Action name="view_maintain_aspect"/>
  <Action name="view_full_screen"/>
  <Separator lineSeparator="true"/>
  <Menu name="showhide"><text>&amp;Settings</text>
    <Action name="options_show_menubar"/>
    <Action name="options_show_statusbar"/>
    <Separator lineSeparator="true"/>
    <Action name="options_show_playlist"/>
    <Action name="options_show_library"/>
    <Action name="options_show_log"/>
    <Separator lineSeparator="true"/>
    <Action name="options_show_toolbar"/>
    <Action name="settings_progress_toolbar"/>
    <Action name="settings_volume_toolbar"/>
  </Menu>
  <Separator lineSeparator="true"/>
  <Action name="file_quit"/>
</Menu>
<Menu name="library_popup">
  <Action name="library_play"/>
  <Action name="library_play_next"/>
  <Action name="library_queue"/>
  <Action name="library_queue_next"/>
  <Menu name="library_add_to"><text>Add &amp;to</text>
    <ActionList name="library_add_to_playlist"/>
    <Action name="library_add_to_new_playlist"/>
    <Action name="library_add_to_playlists"/>
    <Action name="library_add_to_collection"/>
  </Menu>
  <Separator lineSeparator="true"/>
  <Menu name="library_add"><text>&amp;Add</text>
    <Action name="library_add_files"/>
    <Action name="library_add_url"/>
    <Action name="library_add_group"/>
  </Menu>
  <Action name="library_select_all"/>
  <Action name="library_move_up"/>
  <Action name="library_move_down"/>
  <Action name="library_remove"/>
  <Separator lineSeparator="true"/>
  <Action name="library_rename"/>
  <Menu name="library_edit"><text>&amp;Edit</text>
    <ActionList name="library_edit"/>
  </Menu>
  <Action name="library_properties"/>
  <Separator lineSeparator="true"/>
  <Menu name="library_columns"><text>&amp;Columns</text>
    <ActionList name="library_columns"/>
  </Menu>
  <Menu name="library_go"><text>&amp;Go</text>
    <ActionList name="library_history"/>
    <ActionList name="library_go_to_list"/>
    <Action name="library_go_back"/>
    <Action name="library_go_forward"/>
    <Action name="library_go_up"/>
    <Action name="library_go_down"/>
    <Action name="library_go_to_origin"/>
  </Menu>
</Menu>
<Menu name="playlist_popup">
  <Action name="file_open"/>
  <Action name="file_open_url"/>
  <Menu name="play_list"><text>Play &amp;List</text>
    <ActionList name="play_list"/>
  </Menu>
  <Menu name="file_recent"><text>Play &amp;Recent</text>
    <ActionList name="file_recent"/>
  </Menu>
  <ActionList name="file_devices"/>
  <Separator lineSeparator="true"/>
  <Action name="player_next"/>
  <Action name="player_previous"/>
  <Action name="player_loop"/>
  <Action name="player_shuffle"/>
  <Separator lineSeparator="true"/>
  <Action name="playlist_edit"/>
  <Menu name="playlist_add"><text>&amp;Add</text>
    <Action name="playlist_add_files"/>
    <Action name="playlist_add_url"/>
  </Menu>
  <Menu name="playlist_add_to"><text>Add &amp;to</text>
    <ActionList name="playlist_add_to_playlist"/>
    <Action name="playlist_add_to_playlists"/>
    <Action name="playlist_add_to_collection"/>
  </Menu>
</Menu>
<Menu name="log_popup">
  <Action name="log_select_all"/>
  <Action name="log_copy"/>
  <Action name="log_clear"/>
</Menu>
</kpartgui>
