( cd usr/share/doc/HTML/da/kplayer ; rm -rf common )
( cd usr/share/doc/HTML/da/kplayer ; ln -sf /usr/share/doc/HTML/da/common common )
( cd usr/share/doc/HTML/en/kplayer ; rm -rf common )
( cd usr/share/doc/HTML/en/kplayer ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/es/kplayer ; rm -rf common )
( cd usr/share/doc/HTML/es/kplayer ; ln -sf /usr/share/doc/HTML/es/common common )
( cd usr/share/doc/HTML/it/kplayer ; rm -rf common )
( cd usr/share/doc/HTML/it/kplayer ; ln -sf /usr/share/doc/HTML/it/common common )
( cd usr/share/doc/HTML/pt/kplayer ; rm -rf common )
( cd usr/share/doc/HTML/pt/kplayer ; ln -sf /usr/share/doc/HTML/pt/common common )
( cd usr/share/doc/HTML/sv/kplayer ; rm -rf common )
( cd usr/share/doc/HTML/sv/kplayer ; ln -sf /usr/share/doc/HTML/sv/common common )
